This mod allows your units to auto explore. The plot that your unit decides to go to is based on a heuristic.

The basic idea of the algorithm is to have each unit look at the tiles around it and determine which tile to move to next. Once a unit selects a tile it can get the path it will traverse and mark those plots as reserved. Any other units searching for a destination tile will try to avoid those reserved plots.

If you want to adjust the behavior of auto exploration, you can do so within settings.js. Those are the parameters that control the heuristic for choosing a path for a unit. You shouldn't have to mess with exploration-manager unless you're trying to learn or really want to.

The pseudocode for the algorithm is as follows:

```
for each unit:
    tiles := getTilesAround(unit)
    priorities := array2d(rows=tiles.length, cols=tiles[0].length, fill=Infinity)

    for each tile in tiles:
        x, y := getXY(tile, unit, priorities)  // get (x, y) within the priorities 2D array
        priorities[y][x] := min(getPriority(tile), priorities[y][x])
        updateSurroundingTilesIfNecessary(tile, x, y)
    end for
    
    paths := getPathsToTiles(unit, tiles)
    W := array2d(rows=tiles.length, cols=tiles[0].length, fill=-Infinity)
    W[unit.location.y][unit.location.x] := 0
    allowablePlots := getValidPlotsAround(unit)
    
    for each path in paths:
        weight := 0
        valid := true
        for each (i, plot) in enumerate(path, 0):
            if plot not in allowablePlots:
                valid := false
                break
            turn := path.turns[i]
            location := GameplayMap.getLocationFromIndex(plot)
            gxy := getXY(location, unit, priorities)
            weight += priorities[gxy.y][gxy.x] * (0.95 ** turn)
        end for

        if not valid:
            continue
        
        if weight is better at this tile:
            update weight for ending tile of the path
    end for

    bestTarget := {x: -9999, y: -9999}
    maxValue := -Infinity
    for row in W.rows:
        for col in W.cols:
            if W[row][col] > maxValue:
                bestTarget := getMapLocationFromGridLocation(row, col, W, unit)
                maxValue := W[row][col]
        end for
    end for
    
    reservePath(unit, bestTarget)
end for
```
